# djangocms-misc

[![CI](https://github.com/bnzk/djangocms-misc/actions/workflows/ci.yml/badge.svg)](https://github.com/bnzk/djangocms-misc/actions/workflows/ci.yml)
[![Version](https://img.shields.io/pypi/v/djangocms-misc.svg?style=flat-square "Version")](https://pypi.python.org/pypi/djangocms-misc/)
[![Licence](https://img.shields.io/github/license/bnzk/djangocms-misc.svg?style=flat-square "Licence")](https://pypi.python.org/pypi/djangocms-misc/)
[![PyPI Downloads](https://img.shields.io/pypi/dm/djangocms-misc?style=flat-square "PyPi Downloads")](https://pypistats.org/packages/djangocms-misc)

Development and docs on https://github.com/bnzk/djangocms-misc/
